searchData={"items":[{"type":"module","title":"Pegasus","doc":"converts `peg` files into `NimbleParsec` parsers.\n\nFor documentation on this peg format:  https://www.piumarta.com/software/peg/peg.1.html\n\nTo use, drop this in your model:\n\n```\ndefmodule MyModule\n  require Pegasus\n\n  Pegasus.parser_from_string(\"\"\"\n  foo <- \"foo\" \"bar\"\n  \"\"\", foo: [parser: true])\nend\n```\n\nSee `NimbleParsec` for the description of the output.\n\n```\nMyModule.foo(\"foobar\") # ==> {:ok, [\"foo\", \"bar\"], ...}\n```\n\n> #### Capitalized Identifiers {: .warning}\n>\n> for capitalized identifiers, you will have to use `apply/3` to call the\n> function, or you may wrap it in another combinator like so:\n>\n> ```elixir\n> defmodule Capitalized do\n>   require Pegasus\n>   import NimbleParsec\n>\n>   Pegasus.parser_from_string(\"Foo <- 'foo'\")\n>\n>   defparsec :parse, parsec(:Foo)\n> end\n> ```\n\nYou may also load a parser from a file using `parser_from_file/2`.","ref":"Pegasus.html"},{"type":"module","title":"Parser Options - Pegasus","doc":"Parser options are passed as a keyword list after the parser defintion\nstring (or file).  The keys for the options are the names of the combinators,\nfollowed by a keyword list of supplied options, which are applied in the\nspecified order:\n\n### `:start_position`\n\nWhen true, drops a map `%{line:  , column:  , offset:  }` into\nthe arguments for this keyword at the front of its list.\n\n### `:collect`\n\nYou may collect the contents of a combinator using the `collect: true` option.\nIf this combinator calls other combinators, they must leave only iodata (no\ntags, no tokens) in the arguments list.\n\n### `:token`\n\nYou may substitute the contents of any combinator with a token (usually an atom).\nThe following conditions apply:\n\n- `token: false` - no token (default)\n- `token: true` - token is set to the atom name of the combinator\n- `token:  ` - token is set to the value of setting\n\n### `:tag`\n\nYou may tag the contents of your combinator using the `:tag` option.  The\nfollowing conditions apply:\n\n- `tag: false` - No tag (default)\n- `tag: true` - Use the combinator name as the tag.\n- `tag:  ` - Use the supplied atom as the tag.\n\n### `:post_traverse`\n\nYou may supply a post_traversal for any parser.  See `NimbleParsec` for how to\nimplement post-traversal functions.  These are defined by passing a keyword list\nto the `parser_from_file/2` or `parser_from_string/2` function.\n\n> #### Post-traversal arguments are reversed {: .info }\n>\n> Note that the second argument for a post-traversal function receives a list of\n> results from traversal in *reversed* order.\n\n### `:ignore`\n\nIf true, clears the arguments from the list.\n\n#### Example\n\n```\nPegasus.parser_from_string(\"\"\"\n  foo <- \"foo\" \"bar\"\n  \"\"\",\n  foo: [post_traverse: {:some_function, []}]\n)\n\ndefp foo(rest, [\"bar\", \"foo\"], context, {_line, _col}, _bytes) do\n  {rest, [:parsed], context}\nend\n```\n\n### `:parser`\n\nYou may sepecify to export a combinator as a parser by specifying `parser: true`.\nBy default, only a combinator will be generated.  See `NimbleParsec.defparsec/3`\nto understand the difference.\n\n#### Example\n\n```\nPegasus.parser_from_string(\"\"\"\n  foo <- \"foo\" \"bar\"\n  \"\"\", foo: [parser: true]\n)\n```\n\n### `:export`\n\nYou may sepecify to export a combinator as a public function by specifying `export: true`.\nBy default, the combinators are private functions.\n\n#### Example\n\n```\nPegasus.parser_from_string(\"\"\"\n  foo <- \"foo\" \"bar\"\n  \"\"\", foo: [export: true]\n)\n```\n\n### `:alias`\n\nYou may specify your own combinators to be run in place of what's in the grammar.\nThis is useful if the grammar is wrong or contains content that can't be run for\nsome reason.\n\n#### Example\n\n```\nPegasus.parser_from_string(\"\"\"\n  foo <- \"foo\"\n\"\"\", foo: [alias: :my_combinator])\n```","ref":"Pegasus.html#module-parser-options"},{"type":"module","title":"Not implemented features - Pegasus","doc":"Actions, which imply the use of C code, are not implemented.  These currently fail to parse\nbut in the future they may silently do nothing.","ref":"Pegasus.html#module-not-implemented-features"},{"type":"function","title":"Pegasus.parse/2","doc":"Parses the given `binary` as parse.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the parse (start position) as `{line, offset_to_start_of_line}`.\n\nTo column where the error occurred can be inferred from `byte_offset - offset_to_start_of_line`.","ref":"Pegasus.html#parse/2"},{"type":"function","title":"Options - Pegasus.parse/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"Pegasus.html#parse/2-options"},{"type":"macro","title":"Pegasus.parser_from_ast/2","doc":"","ref":"Pegasus.html#parser_from_ast/2"},{"type":"macro","title":"Pegasus.parser_from_file/2","doc":"","ref":"Pegasus.html#parser_from_file/2"},{"type":"macro","title":"Pegasus.parser_from_string/2","doc":"","ref":"Pegasus.html#parser_from_string/2"},{"type":"extras","title":"Pegasus","doc":"# Pegasus\n\nInstrumentable Peg Parser for Elixir, based on NimbleParsec\n\nFor documentation on this peg format:\n\nhttps://www.piumarta.com/software/peg/peg.1.html","ref":"readme.html"},{"type":"extras","title":"Installation - Pegasus","doc":"```elixir\ndef deps do\n  [\n    {:pegasus, \"~> 0.2.4\"}\n  ]\nend\n```","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}